"""
Kaizen MCP Integration

This package contains MCP (Model Context Protocol) server implementations
for Kaizen framework.

Sub-packages:
- builtin_server: MCP server providing Kaizen's 12 builtin tools
"""

__all__ = []
